import { useState, useEffect, useRef } from 'react';
import { useNavigate } from 'react-router-dom';
import { ArrowLeft, Download, Wallet, CreditCard, Lightbulb, BrainCircuit } from 'lucide-react';
import Navbar from '@/components/Navbar';
import PredictionCard from '@/components/PredictionCard';
import RiskMatrix from '@/components/RiskMatrix';
import { 
  RiskScoreChart, 
  PaymentHistoryChart, 
  SpendingTrendChart, 
  ComparisonChart 
} from '@/components/DataVisualizations';
import { 
  generatePaymentHistoryData, 
  generateSpendingTrendData, 
  generateComparisonData 
} from '@/lib/mockData';
import { toast } from "sonner";
import { 
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger
} from "@/components/ui/accordion";
import jsPDF from 'jspdf';
import html2canvas from 'html2canvas';

const ResultsDashboard = () => {
  const navigate = useNavigate();
  const [results, setResults] = useState(null);
  const [clientData, setClientData] = useState(null);
  const [paymentData, setPaymentData] = useState([]);
  const [spendingData, setSpendingData] = useState([]);
  const [comparisonData, setComparisonData] = useState([]);
  const [isExporting, setIsExporting] = useState(false);
  const reportRef = useRef(null);

  useEffect(() => {
    // Scroll to top on load
    window.scrollTo(0, 0);
    
    // Get data from sessionStorage
    const storedResults = sessionStorage.getItem('predictionResults');
    const storedClientData = sessionStorage.getItem('clientData');
    
    if (!storedResults || !storedClientData) {
      // No data found, redirect to form page
      toast.error("No assessment data found", {
        description: "Please complete the assessment form first.",
      });
      navigate('/prediction');
      return;
    }
    
    try {
      // Parse the stored data
      const parsedResults = JSON.parse(storedResults);
      const parsedClientData = JSON.parse(storedClientData);
      
      setResults(parsedResults);
      setClientData(parsedClientData);
      
      // Generate mock data for charts - passing default data if needed
      setPaymentData(generatePaymentHistoryData(parsedResults.riskScore));
      setSpendingData(generateSpendingTrendData(parsedResults.riskScore));
      setComparisonData(generateComparisonData(parsedResults.additionalMetrics));
    } catch (error) {
      console.error("Error parsing assessment data:", error);
      toast.error("Error loading assessment data", {
        description: "Please try again or start a new assessment.",
      });
      navigate('/prediction');
    }
  }, [navigate]);

  const handleExportPDF = async () => {
    if (!reportRef.current) return;
    
    setIsExporting(true);
    toast.info("Preparing PDF for download...", {
      duration: 2000,
    });

    try {
      // Create a temporary container with white background for better PDF rendering
      const originalBackground = reportRef.current.style.background;
      reportRef.current.style.background = 'white';
      
      const canvas = await html2canvas(reportRef.current, {
        scale: 1.5, // Higher quality
        useCORS: true,
        logging: false,
        allowTaint: true,
        backgroundColor: '#ffffff'
      });
      
      // Restore original background
      reportRef.current.style.background = originalBackground;

      const imgData = canvas.toDataURL('image/png');
      const pdf = new jsPDF('p', 'mm', 'a4');
      const pdfWidth = pdf.internal.pageSize.getWidth();
      const pdfHeight = pdf.internal.pageSize.getHeight();
      const imgWidth = canvas.width;
      const imgHeight = canvas.height;
      const ratio = Math.min(pdfWidth / imgWidth, pdfHeight / imgHeight);
      const imgX = (pdfWidth - imgWidth * ratio) / 2;
      const imgY = 10; // Top margin

      // Add company and client information header
      pdf.setFontSize(18);
      pdf.setTextColor(64, 64, 64);
      pdf.text('CIFT FinTap - Credit Assessment Report', pdfWidth / 2, 10, { align: 'center' });
      
      pdf.setFontSize(12);
      pdf.setTextColor(100, 100, 100);
      const clientName = clientData?.name || 'Client';
      const date = new Date().toLocaleDateString();
      pdf.text(`Client: ${clientName} | Date: ${date}`, pdfWidth / 2, 20, { align: 'center' });
      
      // Add the main content
      pdf.addImage(imgData, 'PNG', imgX, imgY + 15, imgWidth * ratio, imgHeight * ratio);

      // Save PDF
      pdf.save(`FinTap_Credit_Assessment_${clientName.replace(/\s+/g, '_')}_${date.replace(/\//g, '-')}.pdf`);

      toast.success("PDF Export Completed", {
        description: "Your assessment report has been downloaded.",
      });
    } catch (error) {
      console.error("Error generating PDF:", error);
      toast.error("PDF Export Failed", {
        description: "There was an error generating your PDF. Please try again.",
      });
    } finally {
      setIsExporting(false);
    }
  };

  // Format currency for display
  const formatCurrency = (amount) => {
    return new Intl.NumberFormat('en-US', {
      style: 'currency',
      currency: 'BDT',
      maximumFractionDigits: 0
    }).format(amount);
  };

  if (!results || !clientData) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="text-center">
          <div className="w-16 h-16 border-4 border-brand-blue border-t-transparent rounded-full animate-spin mx-auto mb-4"></div>
          <p className="text-lg">Loading assessment results...</p>
        </div>
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-white to-gray-50">
      <Navbar />
      
      <main className="pt-32 pb-16">
        <div className="container max-w-6xl mx-auto px-4">
          <button 
            onClick={() => navigate(-1)}
            className="flex items-center gap-1 text-muted-foreground hover:text-foreground transition-colors mb-8"
          >
            <ArrowLeft size={16} />
            <span>Back</span>
          </button>
          
          <div className="flex flex-col md:flex-row justify-between items-start md:items-center gap-4 mb-8 animate-fade-up">
            <div>
              <h1 className="heading-lg mb-2">Credit Risk Assessment Results</h1>
              <p className="text-lg text-muted-foreground">
                Comprehensive analysis and risk prediction for {clientData.name || 'Client'}
              </p>
            </div>
            
            <button 
              onClick={handleExportPDF} 
              className="button-secondary flex items-center gap-2"
              disabled={isExporting}
            >
              <Download size={18} />
              {isExporting ? "Generating PDF..." : "Export Report"}
            </button>
          </div>
          
          <div ref={reportRef}>
            {/* AI Insights Section - Only show if AI data is available */}
            {results.aiInsights && (
              <div className="glass-panel p-6 mb-6 animate-fade-up">
                <div className="flex items-start mb-4">
                  <div className="p-3 rounded-full bg-purple-50 mr-4">
                    <BrainCircuit className="h-6 w-6 text-purple-600" />
                  </div>
                  <div>
                    <h3 className="heading-sm mb-2">AI-Enhanced Risk Assessment</h3>
                    <p className="text-sm text-muted-foreground">
                      Insights powered by advanced AI models including Random Forest and XGBoost
                    </p>
                  </div>
                </div>

                <Accordion type="single" collapsible className="w-full">
                  <AccordionItem value="assessment">
                    <AccordionTrigger className="text-lg font-medium">
                      Risk Assessment
                    </AccordionTrigger>
                    <AccordionContent>
                      <p className="text-muted-foreground mb-4">{results.aiInsights.assessment}</p>
                    </AccordionContent>
                  </AccordionItem>

                  <AccordionItem value="key-factors">
                    <AccordionTrigger className="text-lg font-medium">
                      Key Risk Factors
                    </AccordionTrigger>
                    <AccordionContent>
                      <ul className="list-disc list-inside space-y-2">
                        {results.aiInsights.keyFactors.map((factor, index) => (
                          <li key={index} className="text-muted-foreground">{factor}</li>
                        ))}
                      </ul>
                    </AccordionContent>
                  </AccordionItem>

                  <AccordionItem value="improvements">
                    <AccordionTrigger className="text-lg font-medium">
                      Suggestions for Improvement
                    </AccordionTrigger>
                    <AccordionContent>
                      <ul className="list-disc list-inside space-y-2">
                        {results.aiInsights.improvementSuggestions.map((suggestion, index) => (
                          <li key={index} className="text-muted-foreground">{suggestion}</li>
                        ))}
                      </ul>
                    </AccordionContent>
                  </AccordionItem>

                  <AccordionItem value="model-comparison">
                    <AccordionTrigger className="text-lg font-medium">
                      Model Comparison
                    </AccordionTrigger>
                    <AccordionContent>
                      <p className="text-muted-foreground">{results.aiInsights.modelComparison}</p>
                    </AccordionContent>
                  </AccordionItem>
                </Accordion>
              </div>
            )}
            
            {/* Recommendations Section */}
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mb-6 animate-fade-up" style={{ animationDelay: '0.05s' }}>
              <div className="glass-panel p-6 flex items-start">
                <div className="p-3 rounded-full bg-green-50 mr-4">
                  <Wallet className="h-6 w-6 text-green-600" />
                </div>
                <div>
                  <h3 className="heading-sm mb-2">Recommended Loan Amount</h3>
                  <p className="text-3xl font-bold text-brand-blue">{formatCurrency(results.recommendedLoanAmount)}</p>
                  <p className="text-sm text-muted-foreground mt-1">
                    Based on income, risk profile, and debt-to-income ratio
                  </p>
                </div>
              </div>
              
              <div className="glass-panel p-6 flex items-start">
                <div className="p-3 rounded-full bg-blue-50 mr-4">
                  <CreditCard className="h-6 w-6 text-blue-600" />
                </div>
                <div>
                  <h3 className="heading-sm mb-2">Recommended Credit Card Limit</h3>
                  <p className="text-3xl font-bold text-brand-blue">{formatCurrency(results.recommendedCreditCardLimit)}</p>
                  <p className="text-sm text-muted-foreground mt-1">
                    Based on monthly income and overall risk assessment
                  </p>
                </div>
              </div>
            </div>
            
            <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
              <div className="lg:col-span-1 animate-fade-up">
                <PredictionCard 
                  riskScore={results.riskScore} 
                  defaultProbability={results.defaultProbability}
                  clientName={clientData.name || 'Client'} 
                />
              </div>
              
              <div className="lg:col-span-2">
                <div className="glass-panel p-6 h-full animate-fade-up" style={{ animationDelay: '0.1s' }}>
                  <h3 className="heading-sm mb-4">Risk Score Distribution</h3>
                  <RiskScoreChart riskScore={results.riskScore} />
                  <div className="mt-4 text-center">
                    <p className="text-muted-foreground">
                      Client's risk score of <span className="font-semibold text-foreground">{results.riskScore}</span> falls in the 
                      {' '}
                      <span className="font-semibold text-foreground">
                        {results.riskScore < 20 ? 'Very Low' : 
                        results.riskScore < 40 ? 'Low' : 
                        results.riskScore < 60 ? 'Moderate' : 
                        results.riskScore < 80 ? 'High' : 'Very High'} Risk
                      </span> category
                    </p>
                  </div>
                </div>
              </div>
            </div>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mt-6">
              <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.2s' }}>
                <h3 className="heading-sm mb-4">Payment History Trends</h3>
                <PaymentHistoryChart paymentData={paymentData} />
                <div className="mt-4 text-sm text-muted-foreground">
                  <p>
                    Chart shows payment history for the last 12 months.
                    Value of 1 indicates on-time payment, 0 indicates missed payment.
                  </p>
                </div>
              </div>
              
              <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.3s' }}>
                <h3 className="heading-sm mb-4">Income vs. Spending Trends</h3>
                <SpendingTrendChart spendingData={spendingData} />
                <div className="mt-4 text-sm text-muted-foreground">
                  <p>
                    Monthly income and spending patterns over the last 12 months.
                    Consistent gap between income and spending indicates financial stability.
                  </p>
                </div>
              </div>
              
              <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.4s' }}>
                <h3 className="heading-sm mb-4">Industry Benchmark Comparison</h3>
                <ComparisonChart comparisonData={comparisonData} />
                <div className="mt-4 text-sm text-muted-foreground">
                  <p>
                    Client's financial metrics compared to industry averages.
                    Higher values are better for Credit Score and Payment Reliability, 
                    lower values are better for DTI Ratio and Credit Utilization.
                  </p>
                </div>
              </div>
              
              <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.5s' }}>
                <h3 className="heading-sm mb-4">Key Risk Factors</h3>
                <div className="space-y-4">
                  <div>
                    <div className="flex justify-between items-center mb-1">
                      <span className="font-medium">Credit Score</span>
                      <span className={results.additionalMetrics.creditScore > 700 ? "text-green-600" : "text-yellow-600"}>
                        {results.additionalMetrics.creditScore}
                      </span>
                    </div>
                    <div className="w-full bg-gray-100 rounded-full h-2">
                      <div 
                        className="bg-brand-blue h-2 rounded-full" 
                        style={{ width: `${(results.additionalMetrics.creditScore / 850) * 100}%` }}
                      ></div>
                    </div>
                  </div>
                  
                  <div>
                    <div className="flex justify-between items-center mb-1">
                      <span className="font-medium">DTI Ratio</span>
                      <span className={results.additionalMetrics.dtiRatio < 36 ? "text-green-600" : "text-yellow-600"}>
                        {results.additionalMetrics.dtiRatio}%
                      </span>
                    </div>
                    <div className="w-full bg-gray-100 rounded-full h-2">
                      <div 
                        className="bg-brand-blue h-2 rounded-full" 
                        style={{ width: `${results.additionalMetrics.dtiRatio}%` }}
                      ></div>
                    </div>
                  </div>
                  
                  <div>
                    <div className="flex justify-between items-center mb-1">
                      <span className="font-medium">Payment Reliability</span>
                      <span className={results.additionalMetrics.paymentReliability > 80 ? "text-green-600" : "text-yellow-600"}>
                        {results.additionalMetrics.paymentReliability}%
                      </span>
                    </div>
                    <div className="w-full bg-gray-100 rounded-full h-2">
                      <div 
                        className="bg-brand-blue h-2 rounded-full" 
                        style={{ width: `${results.additionalMetrics.paymentReliability}%` }}
                      ></div>
                    </div>
                  </div>
                  
                  <div>
                    <div className="flex justify-between items-center mb-1">
                      <span className="font-medium">Credit Utilization</span>
                      <span className={results.additionalMetrics.creditUtilization < 30 ? "text-green-600" : "text-yellow-600"}>
                        {results.additionalMetrics.creditUtilization}%
                      </span>
                    </div>
                    <div className="w-full bg-gray-100 rounded-full h-2">
                      <div 
                        className="bg-brand-blue h-2 rounded-full" 
                        style={{ width: `${results.additionalMetrics.creditUtilization}%` }}
                      ></div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </main>
    </div>
  );
};

export default ResultsDashboard;
